forAll(fluid.movingPhases(), movingPhasei)
{
    const phaseModel& phase = fluid.movingPhases()[movingPhasei];
    const volVectorField& UAlpha = phase.U();
    const PtrList<volScalarField> dmdts = fluid.dmdts();

    const dimensionedScalar ZERO(dimensionSet(1, -3, -1, 0, 0), Zero);

    dmdtUEqns.set
    (
        phase.index(),
        (
            fvm::Sp(ZERO, UAlpha)
          + fvm::Su(Zero, UAlpha)
        )
    );

    volScalarField source
    (
        volScalarField::New
        (
            IOobject::groupName("source", phase.name()),
            mesh,
            dimensionedScalar(dimDensity/dimTime, 0)
        )
    );

    if (fvModels.addsSupToField(rho.name()))
    {
        source += fvModels.source(phase, rho)&rho;
    }

    if (dmdts.set(phase.index()))
    {
        source += dmdts[phase.index()];
    }

    dmdtUEqns[phase.index()] += fvm::SuSp(source, UAlpha);
}

initZeroPtrList
(
    dmdtPhiCoeffs,
    mesh,
    dimensionSet(1, 0, -2, 0, 0),
    "dmdtPhiCoeff"
);

// Add mass sources
// Inspired by MomentumTransferPhaseSystem::addDmdtUfs() but with fvm::SuSp()
// instead of fvm::Sp()
forAllConstIter(phaseSystem::dmdtfTable, fluid.dmdtfsPhaseTransfer(), dmdtfIter)
{
    const phasePairKey& key = dmdtfIter.key();
    const phasePair& pair(fluid.phasePairs()[key]);

    const volScalarField dmdtf(Pair<word>::compare(pair, key)**dmdtfIter());

    phaseModel& phase1 = phases[pair.phase1().name()];
    phaseModel& phase2 = phases[pair.phase2().name()];

    const volScalarField dmdtf21(posPart(dmdtf));
    const volScalarField dmdtf12(negPart(dmdtf));

    dmdtUEqns[pair.phase1().index()] -=
        dmdtf21*phase2.U() + fvm::SuSp(dmdtf12, phase1.URef());
    dmdtPhiCoeffs[pair.phase1().index()] +=
        fvc::interpolate(dmdtf21)*MRF.absolute(phase2.phi());

    dmdtUEqns[pair.phase2().index()] +=
        dmdtf12*phase1.U() - fvm::SuSp(-dmdtf21, phase2.URef());
    dmdtPhiCoeffs[pair.phase2().index()] -=
        fvc::interpolate(dmdtf12)*MRF.absolute(phase1.phi());
}
