/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | (C) 2019 Helmholtz-Zentrum Dresden-Rossendorf
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::SGSdelta

Description
    Abstract base class for SGS deltas

See also
    Foam::LESdelta

SourceFiles
    SGSdelta.C

\*---------------------------------------------------------------------------*/

#ifndef SGSdelta_H
#define SGSdelta_H

#include "volFields.H"
#include "runTimeSelectionTables.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                          Class SGSdelta Declaration
\*---------------------------------------------------------------------------*/

class SGSdelta
{
protected:

    // Protected data

        //- Reference to the mesh
        const fvMesh& mesh_;

        volScalarField delta_;


public:

    //- Runtime type information
    TypeName("SGSdelta");


    // Declare run-time constructor selection table

        declareRunTimeSelectionTable
        (
            autoPtr,
            SGSdelta,
            dictionary,
            (
                const word& name,
                const fvMesh& mesh,
                const dictionary& dict
            ),
            (name, mesh, dict)
        );


    // Constructors

        //- Construct from name and mesh
        SGSdelta
        (
            const word& name,
            const fvMesh& mesh
        );

        //- Disallow default bitwise copy construction
        SGSdelta(const SGSdelta&) = delete;

    // Selectors

        //- Return a reference to the selected SGS delta
        static autoPtr<SGSdelta> New
        (
            const word& name,
            const fvMesh& mesh,
            const dictionary& dict
        );


    //- Destructor
    virtual ~SGSdelta()
    {}


    // Member Functions

        //- Read the SGSdelta dictionary
        virtual void read(const dictionary&) = 0;

        // Correct values
        virtual void correct() = 0;


    // Member Operators

        void operator=(const SGSdelta&) = delete;

        virtual operator const volScalarField&() const
        {
            return delta_;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
