/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diffusiveMassTransferModels::constantShDiffusiveMassTransfer

Description
    Model which applies a user provided constant Sherwood number for
    interfacial mass transfer.

SourceFiles
    constantSherwoodNumber.C

\*---------------------------------------------------------------------------*/

#ifndef constantSherwoodNumber_H
#define constantSherwoodNumber_H

#include "diffusiveMassTransferModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

class phasePair;

namespace diffusiveMassTransferModels
{

/*---------------------------------------------------------------------------*\
                   Class constantSherwoodNumber Declaration
\*---------------------------------------------------------------------------*/

class constantSherwoodNumber
:
    public diffusiveMassTransferModel
{
    // Private Data

        //- Sherwood number
        const dimensionedScalar Sh_;


public:

    //- Runtime type information
    TypeName("constantSherwoodNumber");


    // Constructors

        //- Construct from components
        constantSherwoodNumber
        (
            const dictionary& dict,
            const phasePair& pair
        );


    //- Destructor
    virtual ~constantSherwoodNumber();


    // Member Functions

        //- The implicit mass transfer coefficient
        virtual tmp<volScalarField> K() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace diffusiveMassTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
