/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2019-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "KetterlWeberNumber.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace subGridSurfaceTensionModels
{
    defineTypeNameAndDebug(KetterlWeberNumber, 0);
    addToRunTimeSelectionTable
    (
        subGridSurfaceTensionModel,
        KetterlWeberNumber,
        dictionary
    );
}
}


// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::subGridSurfaceTensionModels::KetterlWeberNumber::WeCrit() const
{
    return
        volScalarField::New
        (
            IOobject::groupName("WeCrit", pair().name()),
            mesh(),
            WeCrit_
        );
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::subGridSurfaceTensionModels::KetterlWeberNumber::KetterlWeberNumber
(
    const dictionary& dict,
    const phasePair& pair
)
:
    WeberNumberModel(dict, pair),

    WeCrit_
    (
        dimensioned<scalar>::lookupOrAddToDict
        (
            "WeCrit",
            this->coeffDict_,
            10
        )
    )
{
    if (type() == typeName)
    {
        this->printCoeffs(type());
    }
}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::subGridSurfaceTensionModels::KetterlWeberNumber::~KetterlWeberNumber()
{}


// ************************************************************************* //
