/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2019-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::subGridSurfaceTensionModel::KetterlWeberNumber

Description
    Sub-grid surface tension with effective Weber number approach.

    Reference:
    \verbatim
        Ketterl, S., Reißmann, M., Klein, M. (2019).
        Large eddy simulation of multiphase flows using the volume of fluid
        method: Part 2 - A-posteriori analysis of liquid jet atomization.
        Experimental and Computational Multiphase Flow, 1(3), 201-211.
    \endverbatim

SourceFiles
    KetterlWeberNumber.C

\*---------------------------------------------------------------------------*/

#ifndef KetterlWeberNumber_H
#define KetterlWeberNumber_H

#include "WeberNumberModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

class phasePair;

namespace subGridSurfaceTensionModels
{

/*---------------------------------------------------------------------------*\
                     Class KetterlWeberNumber Declaration
\*---------------------------------------------------------------------------*/

class KetterlWeberNumber
:
    public WeberNumberModel
{
    // Private data

        //- Critical Weber number
        const dimensionedScalar WeCrit_;


    // Private member functions

        //- Critical Weber number
        virtual tmp<volScalarField> WeCrit() const;


public:

    //- Runtime type information
    TypeName("KetterlWeberNumber");


    // Constructors

        //- Construct from a dictionary and a phase pair
        KetterlWeberNumber
        (
            const dictionary& dict,
            const phasePair& pair
        );


    //- Destructor
    virtual ~KetterlWeberNumber();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace subGridSurfaceTensionModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
