/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2019-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "scaleSimilaritySubGridSurfaceTension.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"
#include "fvcGrad.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace subGridSurfaceTensionModels
{
    defineTypeNameAndDebug(scaleSimilaritySubGridSurfaceTension, 0);
    addToRunTimeSelectionTable
    (
        subGridSurfaceTensionModel,
        scaleSimilaritySubGridSurfaceTension,
        dictionary
    );
}
}


// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::volVectorField>
Foam::subGridSurfaceTensionModels::scaleSimilaritySubGridSurfaceTension::
subGridSurfaceTensionForce
(
    const volScalarField& K
) const
{
    return
        filter_(this->sigma()*K*gradAlpha())
       -filter_(this->sigma())*filter_(K)*filter_(gradAlpha());
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::subGridSurfaceTensionModels::scaleSimilaritySubGridSurfaceTension::
scaleSimilaritySubGridSurfaceTension
(
    const dictionary& dict,
    const phasePair& pair
)
:
    subGridSurfaceTensionModel(dict, pair),

    filterPtr_(LESfilter::New(mesh(), dict)),
    filter_(filterPtr_())
{
    if (type() == typeName)
    {
        this->printCoeffs(type());
    }
}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::subGridSurfaceTensionModels::scaleSimilaritySubGridSurfaceTension::
~scaleSimilaritySubGridSurfaceTension()
{}


// ************************************************************************* //
