/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2021 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "StrubeljTiselj.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"
#include "surfaceInterpolate.H"
#include "fvcGrad.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace dragModels
{
    defineTypeNameAndDebug(StrubeljTiselj, 0);
    addToRunTimeSelectionTable(dragModel, StrubeljTiselj, dictionary);
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::dragModels::StrubeljTiselj::StrubeljTiselj
(
    const dictionary& dict,
    const phasePair& pair,
    const bool registerObject
)
:
    dragModel(dict, pair, registerObject),
    tau_("Tau", dimless, dict)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::dragModels::StrubeljTiselj::~StrubeljTiselj()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField> Foam::dragModels::StrubeljTiselj::CdRe() const
{
    FatalErrorInFunction
        << "Not implemented."
        << exit(FatalError);

    return tmp<volScalarField>(nullptr);
}


Foam::tmp<Foam::volScalarField> Foam::dragModels::StrubeljTiselj::Ki() const
{
    FatalErrorInFunction
        << "Not implemented."
        << exit(FatalError);

    return tmp<volScalarField>(nullptr);
}


Foam::tmp<Foam::volScalarField> Foam::dragModels::StrubeljTiselj::K() const
{
    return
        max(pair_.phase1(), pair_.phase1().residualAlpha())
       *max(pair_.phase2(), pair_.phase2().residualAlpha())
       *pair_.rho()*tau_/pair_.phase1().mesh().time().deltaT();
}


Foam::tmp<Foam::surfaceScalarField>Foam::dragModels::StrubeljTiselj::Kf() const
{
    return fvc::interpolate(K());
}


// ************************************************************************* //
