/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "Ma.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace inducedTurbulenceModels
{
    defineTypeNameAndDebug(Ma, 0);
    addToRunTimeSelectionTable(inducedTurbulenceModel, Ma, dictionary);
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::inducedTurbulenceModels::Ma::Ma
(
    const dictionary& dict,
    const phasePair& pair
)
:
    inducedTurbulenceModel(dict, pair)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::inducedTurbulenceModels::Ma::~Ma()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::inducedTurbulenceModels::Ma::Ck() const
{
    return min(0.18*pow(pair_.Re(), 0.23), 1.0);
}


Foam::tmp<Foam::volScalarField>
Foam::inducedTurbulenceModels::Ma::Ceps() const
{
    return
        0.3
       *dragModel_.CdRe()
       *pair_.continuous().thermo().nu()
       /sqr(pair_.dispersed().d());
}


// ************************************************************************* //
