/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::inducedTurbulenceModels::Ma

Description
    Bubble-induced turbulence model of Ma et al. (2017).

    Reference:
    \verbatim
        Ma, T., Santarelli, C., Ziegenhein, T., Lucas, D., &
        Fröhlich, J. (2017).
        Direct numerical simulation–based Reynolds-averaged closure for
        bubble-induced turbulence.
        Physical Review Fluids, 2(3), 034301.
    \endverbatim


SourceFiles
    Ma.C

\*---------------------------------------------------------------------------*/

#ifndef Ma_H
#define Ma_H

#include "inducedTurbulenceModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace inducedTurbulenceModels
{

/*---------------------------------------------------------------------------*\
                             Class Ma Declaration
\*---------------------------------------------------------------------------*/

class Ma
:
    public inducedTurbulenceModel
{
public:

    //- Runtime type information
    TypeName("Ma");


    // Constructors

        //- Construct from a dictionary and a phase pair
        Ma
        (
            const dictionary& dict,
            const phasePair& pair
        );


    //- Destructor
    virtual ~Ma();


    // Member Functions

        virtual tmp<volScalarField> Ck() const;

        virtual tmp<volScalarField> Ceps() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace inducedTurbulenceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
