/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "inducedTurbulenceModel.H"
#include "phasePair.H"
#include "surfaceInterpolate.H"
#include "phaseSystem.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
    defineTypeNameAndDebug(inducedTurbulenceModel, 0);
    defineBlendedInterfacialModelTypeNameAndDebug
    (
        inducedTurbulenceModel,
        0
    );

    defineRunTimeSelectionTable(inducedTurbulenceModel, dictionary);
}

const Foam::dimensionSet Foam::inducedTurbulenceModel::
    dimKk(1, -1, -3, 0, 0);

const Foam::dimensionSet Foam::inducedTurbulenceModel::
    dimKeps(1, -1, -4, 0, 0);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::inducedTurbulenceModel::inducedTurbulenceModel
(
    const dictionary& dict,
    const phasePair& pair
)
:
    pair_(pair),
    dragModel_
    (
        pair_.dispersed().fluid().lookupSubModel<dragModel>
        (
            pair_
        )
    )
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::inducedTurbulenceModel::~inducedTurbulenceModel()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField> Foam::inducedTurbulenceModel::Kk() const
{
    return Ck()*dragModel_.K()*magSqr(pair_.Ur());
}


Foam::tmp<Foam::volScalarField> Foam::inducedTurbulenceModel::Keps() const
{
    return Ceps()*Kk();
}

// ************************************************************************* //
