/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::inducedTurbulenceModel

Description

SourceFiles
    inducedTurbulenceModel.C
    inducedTurbulenceModelNew.C

\*---------------------------------------------------------------------------*/

#ifndef inducedTurbulenceModel_H
#define inducedTurbulenceModel_H

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "volFields.H"
#include "dictionary.H"
#include "runTimeSelectionTables.H"
#include "dragModel.H"

namespace Foam
{

class phasePair;

/*---------------------------------------------------------------------------*\
                   Class inducedTurbulenceModel Declaration
\*---------------------------------------------------------------------------*/

class inducedTurbulenceModel
{
protected:

    // Protected data

        //- Phase pair
        const phasePair& pair_;

        //- Reference to phasePair drag model
        const dragModel& dragModel_;

public:

    //- Runtime type information
    TypeName("inducedTurbulenceModel");


    // Declare runtime construction

        declareRunTimeSelectionTable
        (
            autoPtr,
            inducedTurbulenceModel,
            dictionary,
            (
                const dictionary& dict,
                const phasePair& pair
            ),
            (dict, pair)
        );


    // Static data members

        static const dimensionSet dimKk;

        static const dimensionSet dimKeps;


    // Constructors

        // Construct without residual constants
        inducedTurbulenceModel
        (
            const dictionary& dict,
            const phasePair& pair
        );


    //- Destructor
    virtual ~inducedTurbulenceModel();


    // Selectors

        static autoPtr<inducedTurbulenceModel> New
        (
            const dictionary& dict,
            const phasePair& pair
        );


    // Member Functions

        virtual tmp<volScalarField> Ck() const = 0;

        virtual tmp<volScalarField> Ceps() const = 0;

        virtual tmp<volScalarField> Kk() const;

        virtual tmp<volScalarField> Keps() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
