/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "noInducedTurbulence.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace inducedTurbulenceModels
{
    defineTypeNameAndDebug(noInducedTurbulence, 0);
    addToRunTimeSelectionTable
        (
            inducedTurbulenceModel,
            noInducedTurbulence,
            dictionary
        );
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::inducedTurbulenceModels::noInducedTurbulence::
noInducedTurbulence
(
    const dictionary& dict,
    const phasePair& pair
)
:
    inducedTurbulenceModel(dict, pair)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::inducedTurbulenceModels::noInducedTurbulence::
~noInducedTurbulence()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //


Foam::tmp<Foam::volScalarField>
Foam::inducedTurbulenceModels::noInducedTurbulence::Ck() const
{
    const fvMesh& mesh(this->pair_.phase1().mesh());

    return tmp<volScalarField>
    (
        volScalarField::New("Ck", mesh, dimensionedScalar(dimless, Zero))
    );
}


Foam::tmp<Foam::volScalarField>
Foam::inducedTurbulenceModels::noInducedTurbulence::Ceps() const
{
    const fvMesh& mesh(this->pair_.phase1().mesh());

    return tmp<volScalarField>
    (
        volScalarField::New("Ceps", mesh, dimensionedScalar(inv(dimTime), Zero))
    );
}


Foam::tmp<Foam::volScalarField>
Foam::inducedTurbulenceModels::noInducedTurbulence::Kk() const
{
    const fvMesh& mesh(this->pair_.phase1().mesh());

    return tmp<volScalarField>
    (
        volScalarField::New
        (
            "noInducedTurbulence:Kk",
            mesh,
            dimensionedScalar(dimKk, Zero)
        )
    );
}


Foam::tmp<Foam::volScalarField>
Foam::inducedTurbulenceModels::noInducedTurbulence::Keps() const
{
    const fvMesh& mesh(this->pair_.phase1().mesh());

    return tmp<volScalarField>
    (
        volScalarField::New
        (
            "noInducedTurbulence:Keps",
            mesh,
            dimensionedScalar(dimKeps, Zero)
        )
    );
}


// ************************************************************************* //
