/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::RASModels::{Var}StabilizedRASModels

Description
    Add implicit and explicit coefficients to turbulence equations in case, the
    phase volume fraction vanishes.

\*---------------------------------------------------------------------------*/

#ifndef StabilizedRASModels_H
#define StabilizedRASModels_H

#include "phaseModel.H"
#include "fvc.H"
#include "fvm.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace RASModels
{

/*---------------------------------------------------------------------------*\
                    Class VarStabilizedRASModel Declaration
\*---------------------------------------------------------------------------*/

#define makeFieldStabilizedClass(Var, FieldType)                               \
    template<class BasicMomentumTransportModel>                                \
    class Var##StabilizedRASModel                                              \
    :                                                                          \
        public BasicMomentumTransportModel                                     \
    {                                                                          \
        const phaseModel& phase_;                                              \
                                                                               \
                                                                               \
    protected:                                                                 \
                                                                               \
        virtual tmp<fvMatrix<FieldType>> Var##Source() const                   \
        {                                                                      \
            tmp<fvMatrix<FieldType>> tfvm                                      \
            (                                                                  \
                BasicMomentumTransportModel::Var##Source()                     \
            );                                                                 \
                                                                               \
            tfvm.ref() +=                                                      \
                fvc::ddt(phase_.residualAlpha()*this->rho_, this->Var##_)      \
              - fvm::ddt(phase_.residualAlpha()*this->rho_, this->Var##_);     \
                                                                               \
            return tfvm;                                                       \
        }                                                                      \
                                                                               \
                                                                               \
    public:                                                                    \
                                                                               \
        typedef typename BasicMomentumTransportModel::alphaField               \
            alphaField;                                                        \
        typedef typename BasicMomentumTransportModel::rhoField                 \
            rhoField;                                                          \
        typedef typename BasicMomentumTransportModel::transportModel           \
            transportModel;                                                    \
                                                                               \
        TypeName("Var##StabilizedRASModel");                                   \
                                                                               \
                                                                               \
        Var##StabilizedRASModel                                                \
        (                                                                      \
            const alphaField& alpha,                                           \
            const rhoField& rho,                                               \
            const volVectorField& U,                                           \
            const surfaceScalarField& alphaRhoPhi,                             \
            const surfaceScalarField& phi,                                     \
            const transportModel& transport,                                   \
            const word& type = typeName                                        \
        )                                                                      \
        :                                                                      \
            BasicMomentumTransportModel                                        \
            (                                                                  \
                alpha,                                                         \
                rho,                                                           \
                U,                                                             \
                alphaRhoPhi,                                                   \
                phi,                                                           \
                transport,                                                     \
                type                                                           \
            ),                                                                 \
            phase_                                                             \
            (                                                                  \
                U.db().lookupObject<phaseModel>                                \
                (                                                              \
                    IOobject::groupName("alpha", this->transport().name())     \
                )                                                              \
            )                                                                  \
        {                                                                      \
            if (type == typeName)                                              \
            {                                                                  \
                this->printCoeffs(type);                                       \
            }                                                                  \
        }                                                                      \
                                                                               \
        virtual ~Var##StabilizedRASModel()                                     \
        {}                                                                     \
    };

makeFieldStabilizedClass(k, scalar);
makeFieldStabilizedClass(epsilon, scalar);
makeFieldStabilizedClass(omega, scalar);
makeFieldStabilizedClass(R, symmTensor);


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace RASModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
