/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

// RASModel
#define makeUnregisteredTemplatedMomentumTransportModel(BaseModel, SType, Type)\
    typedef Foam::SType##Models::Type<Foam::BaseModel>                         \
        Type##SType##BaseModel;                                                \
    defineNamedTemplateTypeNameAndDebug(Type##SType##BaseModel, 0);            \
                                                                               \
    namespace Foam                                                             \
    {                                                                          \
    namespace SType##Models                                                    \
    {                                                                          \
        typedef Type<BaseModel> Type##SType##BaseModel;                        \
    }                                                                          \
    }


// Stabilization
#include "StabilizedRASModels.H"
#define makeUnregisteredTemplatedStabilizedRASModel(                           \
    BaseModel, Type, TurbVar1, TurbVar2)                                       \
                                                                               \
    typedef                                                                    \
        Foam::RASModels::TurbVar2##StabilizedRASModel                          \
        <                                                                      \
            Foam::RASModels::Type<Foam::BaseModel>                             \
        >                                                                      \
        Type##TurbVar2##Stabilized;                                            \
                                                                               \
    defineTemplateTypeNameAndDebug(Type##TurbVar2##Stabilized, 0);             \
                                                                               \
    typedef                                                                    \
        Foam::RASModels::TurbVar1##StabilizedRASModel                          \
        <                                                                      \
            Type##TurbVar2##Stabilized                                         \
        >                                                                      \
        Type##Stabilized;                                                      \
                                                                               \
    defineTemplateTypeNameAndDebug(Type##Stabilized, 0);                       \
                                                                               \
    namespace Foam                                                             \
    {                                                                          \
    namespace RASModels                                                        \
    {                                                                          \
        typedef                                                                \
            TurbVar1##StabilizedRASModel                                       \
            <                                                                  \
                TurbVar2##StabilizedRASModel                                   \
                <                                                              \
                    Type<BaseModel>                                            \
                >                                                              \
            >                                                                  \
            Type##Stabilized;                                                  \
    }                                                                          \
    }

#define registerTemplatedStabilizedRASModel(BaseModel, Type)                   \
    namespace Foam                                                             \
    {                                                                          \
    namespace RASModels                                                        \
    {                                                                          \
        addToRunTimeSelectionTable                                             \
        (                                                                      \
            RAS##BaseModel,                                                    \
            Type##Stabilized,                                                  \
            dictionary                                                         \
        );                                                                     \
    }                                                                          \
    }


// Induced Turbulence
#include "kItRASModel.H"
#include "epsilonItRASModel.H"
#include "omegaItRASModel.H"
#include "omegaSSTItRASModel.H"
#include "RIsoItRASModel.H"
#include "RAnisoItRASModel.H"
#define makeTemplatedItRASModel(BaseModel, Type, TurbVar1, TurbVar2, Label)    \
    typedef Foam::RASModels::TurbVar2##ItRASModel<Type##Stabilized>            \
        Type##TurbVar2##It;                                                    \
                                                                               \
    defineTemplateTypeNameAndDebug(Type##TurbVar2##It, 0);                     \
                                                                               \
    typedef Foam::RASModels::TurbVar1##ItRASModel<Type##TurbVar2##It>          \
        Type##Label;                                                           \
                                                                               \
    defineTemplateTypeNameAndDebug(Type##Label, 0);                            \
                                                                               \
    namespace Foam                                                             \
    {                                                                          \
    namespace RASModels                                                        \
    {                                                                          \
        typedef TurbVar1##ItRASModel<TurbVar2##ItRASModel<Type##Stabilized>>   \
            Type##Label;                                                       \
                                                                               \
        addToRunTimeSelectionTable                                             \
        (                                                                      \
            RAS##BaseModel,                                                    \
            Type##Label,                                                       \
            dictionary                                                         \
        );                                                                     \
    }                                                                          \
    }


// Egorov Damping
#include "omegaEgorovRASModel.H"
#include "omegaSSTEgorovRASModel.H"
#define makeTemplatedItEgorovRASModel(BaseModel, Type, TurbVar)                \
    typedef Foam::RASModels::TurbVar##EgorovRASModel<Type##It> Type##ItEgorov; \
                                                                               \
    defineTemplateTypeNameAndDebug(Type##ItEgorov, 0);                         \
                                                                               \
    namespace Foam                                                             \
    {                                                                          \
    namespace RASModels                                                        \
    {                                                                          \
        typedef TurbVar##EgorovRASModel<Type##It> Type##ItEgorov;              \
                                                                               \
        addToRunTimeSelectionTable                                             \
        (                                                                      \
            RAS##BaseModel,                                                    \
            Type##ItEgorov,                                                    \
            dictionary                                                         \
        );                                                                     \
    }                                                                          \
    }
