/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2014-2020 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "phaseCompressibleMomentumTransportModel.H"
#include "addToRunTimeSelectionTable.H"
#include "makeMomentumTransportModel.H"
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
#include "makeRASModel.H"
#include "makeStructuralMomentumTransportModel.H"
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#include "laminarModel.H"
#include "RASModel.H"
#include "LESModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

makeMomentumTransportModelTypes
(
    volScalarField,
    volScalarField,
    compressibleMomentumTransportModel,
    PhaseCompressibleMomentumTransportModel,
    phaseModel
);

makeBaseMomentumTransportModel
(
    volScalarField,
    volScalarField,
    compressibleMomentumTransportModel,
    PhaseCompressibleMomentumTransportModel,
    phaseModel
);

#define makeLaminarModel(Type)                                                 \
    makeTemplatedLaminarModel                                                  \
    (phaseModelPhaseCompressibleMomentumTransportModel, laminar, Type)

#define makeRASModel(Type)                                                     \
    makeTemplatedMomentumTransportModel                                        \
    (phaseModelPhaseCompressibleMomentumTransportModel, RAS, Type)

#define makeLESModel(Type)                                                     \
    makeTemplatedMomentumTransportModel                                        \
    (phaseModelPhaseCompressibleMomentumTransportModel, LES, Type)

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
#define makeUnregisteredRASModel(Type)                                         \
    makeUnregisteredTemplatedMomentumTransportModel                            \
    (phaseModelPhaseCompressibleMomentumTransportModel, RAS, Type)

// Requires call of make(Unregistered)RASModel()
#define makeUnregisteredStabilizedRASModel(Type, TurbVar1, TurbVar2)           \
    makeUnregisteredTemplatedStabilizedRASModel                                \
    (phaseModelPhaseCompressibleMomentumTransportModel,                        \
     Type, TurbVar1, TurbVar2)

// Requires call of make(Unregistered)RASModel()
#define makeStabilizedRASModel(Type, TurbVar1, TurbVar2)                       \
    makeUnregisteredStabilizedRASModel(Type, TurbVar1, TurbVar2)               \
    registerTemplatedStabilizedRASModel                                        \
    (phaseModelPhaseCompressibleMomentumTransportModel, Type)

// Requires call of make(Unregistered)StabilizedRASModel()
#define makeLabeledItRASModel(Type, TurbVar1, TurbVar2, Label)                 \
    makeTemplatedItRASModel                                                    \
    (phaseModelPhaseCompressibleMomentumTransportModel, Type,                  \
     TurbVar1, TurbVar2, Label)

// Requires call of make(Unregistered)StabilizedRASModel()
#define makeItRASModel(Type, TurbVar1, TurbVar2)                               \
    makeLabeledItRASModel(Type, TurbVar1, TurbVar2, It)

// Required call of make(Unregistered)ItRASModel()
#define makeItEgorovRASModel(Type, TurbVar)                                    \
    makeTemplatedItEgorovRASModel                                              \
    (phaseModelPhaseCompressibleMomentumTransportModel, Type, TurbVar)

#define makePureStructuralLESModel(Type)                                       \
    makeTemplatedStructuralMomentumTransportModel                              \
    (phaseModelPhaseCompressibleMomentumTransportModel, LES, pure, Type)

#define makeKobayashiStructuralLESModel(Type)                                  \
    makeTemplatedStructuralMomentumTransportModel                              \
    (phaseModelPhaseCompressibleMomentumTransportModel, LES, Kobayashi, Type)

#define makeKleinStructuralLESModel(Type)                                      \
    makeTemplatedStructuralMomentumTransportModel                              \
    (phaseModelPhaseCompressibleMomentumTransportModel, LES, Klein, Type)

#define makeMixedStructuralLESModel(StrType, EvType)                           \
    makeTemplatedMixedStructuralMomentumTransportModel                         \
    (phaseModelPhaseCompressibleMomentumTransportModel, LES, StrType, EvType)
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#include "Stokes.H"
makeLaminarModel(Stokes);

#include "generalizedNewtonian.H"
makeLaminarModel(generalizedNewtonian);

#include "kEpsilon.H"
makeRASModel(kEpsilon);
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
makeUnregisteredStabilizedRASModel(kEpsilon, k, epsilon);
makeItRASModel(kEpsilon, k, epsilon);

#include "kOmega.H"
makeUnregisteredRASModel(kOmega);
makeUnregisteredStabilizedRASModel(kOmega, k, omega);
makeItRASModel(kOmega, k, omega);
makeItEgorovRASModel(kOmega, omega);
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#include "LaheyKEpsilon.H"
makeRASModel(LaheyKEpsilon);

#include "kOmegaSST.H"
makeRASModel(kOmegaSST);
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
makeUnregisteredStabilizedRASModel(kOmegaSST, k, omega);
makeItRASModel(kOmegaSST, k, omegaSST);
makeItEgorovRASModel(kOmegaSST, omegaSST);
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#include "kOmegaSSTSato.H"
makeRASModel(kOmegaSSTSato);
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
makeStabilizedRASModel(kOmegaSSTSato, k, omega);

#include "LRR.H"
makeUnregisteredRASModel(LRR);
makeUnregisteredStabilizedRASModel(LRR, epsilon, R);
makeLabeledItRASModel(LRR, epsilon, RIso, IsoIt);
makeLabeledItRASModel(LRR, epsilon, RAniso, AnisoIt);

#include "SSG.H"
makeUnregisteredRASModel(SSG);
makeUnregisteredStabilizedRASModel(SSG, epsilon, R);
makeLabeledItRASModel(SSG, epsilon, RIso, IsoIt);
makeLabeledItRASModel(SSG, epsilon, RAniso, AnisoIt);
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#include "continuousGasKEpsilon.H"
makeRASModel(continuousGasKEpsilon);

#include "mixtureKEpsilon.H"
makeRASModel(mixtureKEpsilon);

#include "Smagorinsky.H"
makeLESModel(Smagorinsky);

#include "kEqn.H"
makeLESModel(kEqn);

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
#include "NicoudSigma.H"
makeLESModel(NicoudSigma);

#include "scaleSimilarity.H"
makePureStructuralLESModel(scaleSimilarity);

#include "Clark.H"
makePureStructuralLESModel(Clark);

#include "KetterlExtendedGradient.H"
makePureStructuralLESModel(KetterlExtendedGradient);

makeMixedStructuralLESModel(scaleSimilarity, Smagorinsky);
makeMixedStructuralLESModel(scaleSimilarity, NicoudSigma);
makeMixedStructuralLESModel(Clark, Smagorinsky);
makeMixedStructuralLESModel(Clark, NicoudSigma);
makeMixedStructuralLESModel(KetterlExtendedGradient, Smagorinsky);
makeMixedStructuralLESModel(KetterlExtendedGradient, NicoudSigma);

makeKobayashiStructuralLESModel(scaleSimilarity);
makeKobayashiStructuralLESModel(Clark);
makeKobayashiStructuralLESModel(KetterlExtendedGradient);

makeKleinStructuralLESModel(scaleSimilarity);
makeKleinStructuralLESModel(Clark);
makeKleinStructuralLESModel(KetterlExtendedGradient);
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#include "SmagorinskyZhang.H"
makeLESModel(SmagorinskyZhang);

#include "NicenoKEqn.H"
makeLESModel(NicenoKEqn);

#include "continuousGasKEqn.H"
makeLESModel(continuousGasKEqn);

#include "kineticTheoryModel.H"
makeMomentumTransportModel
(phaseModelPhaseCompressibleMomentumTransportModel, RAS, kineticTheoryModel);

#include "phasePressureModel.H"
makeMomentumTransportModel
(phaseModelPhaseCompressibleMomentumTransportModel, RAS, phasePressureModel);


// ************************************************************************* //
