/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2018-2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "interfaceCompressionModel.H"
#include "phasePair.H"
#include "phaseSystem.H"
#include "fvcGrad.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
    defineTypeNameAndDebug(interfaceCompressionModel, 0);
    defineRunTimeSelectionTable(interfaceCompressionModel, dictionary);
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::interfaceCompressionModel::interfaceCompressionModel
(
    const dictionary& dict,
    const phasePair& pair
)
:
    pair_(pair),
    mesh_(pair_.phase1().mesh()),
    deltaN_
    (
        "deltaN",
        1e-8/pow(average(mesh_.V()), 1.0/3.0)
    )
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::interfaceCompressionModel::~interfaceCompressionModel()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::surfaceScalarField> Foam::interfaceCompressionModel::nHatf
(
    const phaseModel& phase
) const
{
    const volScalarField& alpha1 = phase;
    const volScalarField& alpha2 = pair_.otherPhase(phase);

    surfaceVectorField gradAlphaf
    (
        fvc::interpolate(alpha2)*fvc::interpolate(fvc::grad(alpha1))
      - fvc::interpolate(alpha1)*fvc::interpolate(fvc::grad(alpha2))
    );

    return gradAlphaf/(mag(gradAlphaf) + deltaN_) & mesh_.Sf();
}


Foam::tmp<Foam::surfaceScalarField> Foam::interfaceCompressionModel::phirc
(
    const phaseModel& phase
) const
{
    surfaceScalarField phic
    (
        (
            mag(phase.fluid().phi())
          + mag(phase.phi() - pair_.otherPhase(phase).phi())
        )
       /mesh_.magSf()
    );

    return min(C()*phic, max(phic))*nHatf(phase);
}


// ************************************************************************* //
