/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2020-2021 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "addToRunTimeSelectionTable.H"
#include "fvcGrad.H"
#include "gradAlpha.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace interfaceIndicatorMethods
{
    defineTypeNameAndDebug(gradAlpha, 0);
    addToRunTimeSelectionTable
    (
        interfaceIndicatorMethod,
        gradAlpha,
        dictionary
    );
}
}


// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::volVectorField>
Foam::interfaceIndicatorMethods::gradAlpha::gradAlphaPair
(
    const volScalarField& phase1,
    const volScalarField& phase2
) const
{
    return phase2*fvc::grad(phase1) - phase1*fvc::grad(phase2);
}


// * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::interfaceIndicatorMethods::gradAlpha::interfaceIndicator
(
    const phaseModel& phase1,
    const phaseModel& phase2
) const
{
    // Limit the indicator to 1
    return min(mag(gradAlphaPair(phase1, phase2))*dx(), 1.0);
}


const Foam::volScalarField&
Foam::interfaceIndicatorMethods::gradAlpha::dx() const
{
    return delta_();
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::interfaceIndicatorMethods::gradAlpha::gradAlpha
(
    const phaseSystem& fluid
)
:
    interfaceIndicatorMethod(fluid),

    delta_
    (
        SGSdelta::New
        (
            "delta",
            fluid.mesh(),
            fluid.subDict(interfaceIndicatorMethod::typeName)
        )
    )
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::interfaceIndicatorMethods::gradAlpha::~gradAlpha()
{}


// ************************************************************************* //
