/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "addToRunTimeSelectionTable.H"
#include "fvcGrad.H"
#include "useBlendingMethod.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace interfaceIndicatorMethods
{
    defineTypeNameAndDebug(useBlendingMethod, 0);
    addToRunTimeSelectionTable
    (
        interfaceIndicatorMethod,
        useBlendingMethod,
        dictionary
    );
}
}


// * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::interfaceIndicatorMethods::useBlendingMethod::
interfaceIndicator(const phaseModel& phase1, const phaseModel& phase2) const
{
    return
    (
          scalar(1)
        - blendingMethod_->f1(phase1, phase2)
        - blendingMethod_->f2(phase1, phase2)
    );
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::interfaceIndicatorMethods::useBlendingMethod::useBlendingMethod
(
    const phaseSystem& fluid
)
:
    interfaceIndicatorMethod(fluid)
{
    const dictionary& blendingMethodDict
    (
        fluid_.subDict(interfaceIndicatorMethod::typeName).subDict
        (
            "blendingMethod"

        )
    );

    const word blendingName = useBlendingMethod::typeName;

    const phaseSystem::phaseModelPartialList& continuousPhases =
        fluid_.continuousPhases();

    wordList phaseNames;
    forAll(continuousPhases, cphasei)
    {
        phaseNames.append(continuousPhases[cphasei].name());
    }

    blendingMethod_ = blendingMethod::New
    (
        blendingName,
        blendingMethodDict,
        phaseNames
    );
}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::interfaceIndicatorMethods::useBlendingMethod::~useBlendingMethod()
{}


// ************************************************************************* //
