/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2021 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::surfaceTensionForceModels::continuumSurfaceForce

Description
    Continuum surface force approach according to Brackbill et al. (1992)

    Reference:
    \verbatim
        Brackbill, J. U., Kothe, D. B., Zemach, C. (1992).
        A continuum method for modeling surface tension.
        Journal of Computational Physics, 100, 335-354.
    \endverbatim

SourceFiles
    continuumSurfaceForce.C

\*---------------------------------------------------------------------------*/

#ifndef continuumSurfaceForce_H
#define continuumSurfaceForce_H

#include "surfaceTensionForceModel.H"
#include "surfaceFields.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

class phasePair;

namespace surfaceTensionForceModels
{

/*---------------------------------------------------------------------------*\
                    Class continuumSurfaceForce Declaration
\*---------------------------------------------------------------------------*/

class continuumSurfaceForce
:
    public surfaceTensionForceModel
{
    // Private Member Functions

        void correctContactAngle
        (
            surfaceVectorField::Boundary& nHatb,
            const phasePair& pair
        ) const;


protected:

    // Protected Data

        //- Stabilisation for normalisation of the interface normal
        const dimensionedScalar deltaN_;


    // Protected Member Functions

        //- Return the face-based interface normal vector
        virtual tmp<surfaceVectorField> nHatfv(const phasePair& pair) const;


public:

    //- Runtime type information
    TypeName("continuumSurfaceForce");


    // Constructors

        //- Construct from a dictionary and a phase pair
        continuumSurfaceForce(const phaseSystem& fluid);


    //- Destructor
    virtual ~continuumSurfaceForce();


    // Member Functions

        //- Return the curvature of this pair
        virtual tmp<volScalarField> K(const phasePair& pair) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace surfaceTensionForceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
