/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "noSurfaceTensionForce.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace surfaceTensionForceModels
{
    defineTypeNameAndDebug(noSurfaceTensionForce, 0);
    addToRunTimeSelectionTable
    (
        surfaceTensionForceModel,
        noSurfaceTensionForce,
        dictionary
    );
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::surfaceTensionForceModels::noSurfaceTensionForce::noSurfaceTensionForce
(
    const phaseSystem& fluid
)
:
    surfaceTensionForceModel(fluid)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::surfaceTensionForceModels::noSurfaceTensionForce::~noSurfaceTensionForce()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::surfaceTensionForceModels::noSurfaceTensionForce::K
(
    const phasePair& pair
) const
{
    NotImplemented;
    return volScalarField::null();
}


Foam::tmp<Foam::surfaceScalarField>
Foam::surfaceTensionForceModels::noSurfaceTensionForce::surfaceTensionForcef
(
    const phasePair& pair
) const
{
    return
        tmp<surfaceScalarField>
        (
            new surfaceScalarField
            (
                IOobject
                (
                    "surfaceTensionForce",
                    this->fluid_.mesh().time().timeName(),
                    this->fluid_.mesh()
                ),
                this->fluid_.mesh(),
                dimensionedScalar(dimensionSet(1, -2, -2, 0, 0), Zero)
            )
        );
}



// ************************************************************************* //
