/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2020 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::surfaceTensionForceModels::noSurfaceTensionForce

Description
    Deactivated surface tension force.

SourceFiles
    noSurfaceTensionForce.C

\*---------------------------------------------------------------------------*/

#ifndef noSurfaceTensionForce_H
#define noSurfaceTensionForce_H

#include "surfaceTensionForceModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

class phasePair;

namespace surfaceTensionForceModels
{

/*---------------------------------------------------------------------------*\
                    Class noSurfaceTensionForce Declarationc
\*---------------------------------------------------------------------------*/

class noSurfaceTensionForce
:
    public surfaceTensionForceModel
{
public:

    //- Runtime type information
    TypeName("none");


    // Constructors

        //- Construct from a dictionary and a phase pair
        noSurfaceTensionForce(const phaseSystem& fluid);


    //- Destructor
    virtual ~noSurfaceTensionForce();


    // Member Functions

        //- Return the curvature of this pair
        virtual tmp<volScalarField> K(const phasePair& pair) const;

        //- Interface compression flux
        virtual tmp<surfaceScalarField> surfaceTensionForcef
        (
            const phasePair& pair
        ) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace surfaceTensionForceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
