/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2021 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "smoothedContinuumSurfaceForce.H"
#include "addToRunTimeSelectionTable.H"
#include "fvc.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace surfaceTensionForceModels
{
    defineTypeNameAndDebug(smoothedContinuumSurfaceForce, 0);
    addToRunTimeSelectionTable
    (
        surfaceTensionForceModel,
        smoothedContinuumSurfaceForce,
        dictionary
    );
}
}


// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::surfaceTensionForceModels::smoothedContinuumSurfaceForce::smoothen
(
    const volScalarField& vsf
) const
{
    tmp<volScalarField> smoothVsf(vsf);

    for(int iter = 0; iter < nSmoothIters_; iter++)
    {
        smoothVsf = fvc::average(smoothVsf);
    }
    smoothVsf.ref().correctBoundaryConditions();

    return smoothVsf;
}


// * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //

Foam::tmp<Foam::surfaceVectorField>
Foam::surfaceTensionForceModels::smoothedContinuumSurfaceForce::nHatfv
(
    const phasePair& pair
) const
{
    const volScalarField smoothAlpha1(smoothen(pair.phase1()));
    const volScalarField smoothAlpha2(smoothen(pair.phase2()));

    surfaceVectorField gradAlphafv
    (
        fvc::interpolate(smoothAlpha2)
       *fvc::interpolate(fvc::grad(smoothAlpha1))
      - fvc::interpolate(smoothAlpha1)
       *fvc::interpolate(fvc::grad(smoothAlpha2))
    );

    return gradAlphafv/(mag(gradAlphafv) + this->deltaN_);
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::surfaceTensionForceModels::smoothedContinuumSurfaceForce::
smoothedContinuumSurfaceForce
(
    const phaseSystem& fluid
)
:
    continuumSurfaceForce(fluid),
    nSmoothIters_
    (
        fluid.subDict(surfaceTensionForceModel::typeName).
        lookupOrDefault<label>("nSmoothIters", 2)
    )
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::surfaceTensionForceModels::smoothedContinuumSurfaceForce::
~smoothedContinuumSurfaceForce()
{}


// ************************************************************************* //
