/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Unsupported Contributions for OpenFOAM
  ======   //   ||  || ===//   |
  ||  ||  //    ||  // || \\   | Copyright (C) 2019 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "trackPhaseStructures.H"
#include "regionSplit.H"
#include "volFields.H"

// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

template<class Type>
void Foam::functionObjects::trackPhaseStructures::combineFields
(
    Field<Type>& field
)
{
    List<Field<Type>> allValues(Pstream::nProcs());

    allValues[Pstream::myProcNo()] = field;

    Pstream::gatherList(allValues);

    if (Pstream::master())
    {
        field =
            ListListOps::combine<Field<Type>>
            (
                allValues,
                accessOp<Field<Type>>()
            );
    }
}


template<class Type>
const Type& Foam::functionObjects::trackPhaseStructures::lookupOrRead
(
    autoPtr<Type>& fieldPtr,
    const word& name
) const
{
    if (obr_.foundObject<Type>(name))
    {
        Info<< "    Looking up field " << name << endl;
    }
    else
    {
        Info<< "    Reading field " << name << endl;
        fieldPtr.reset
        (
            new Type
            (
                IOobject
                (
                    name,
                    mesh_.time().timeName(),
                    mesh_,
                    IOobject::MUST_READ,
                    IOobject::NO_WRITE
                ),
                mesh_
            )
        );
    }

    const Type& field =
    (
         fieldPtr.valid()
       ? fieldPtr()
       : obr_.lookupObject<Type>(name)
    );

    return field;
}


template<class Type>
Foam::Map<Type> Foam::functionObjects::trackPhaseStructures::regionSum
(
    const regionSplit& regions,
    const Field<Type>& fld
) const
{
    // Per region the sum of fld
    Map<Type> regionToSum(regions.nRegions()/Pstream::nProcs());

    forAll(fld, celli)
    {
        label regionI = regions[celli];

        typename Map<Type>::iterator fnd = regionToSum.find(regionI);
        if (fnd == regionToSum.end())
        {
            regionToSum.insert(regionI, fld[celli]);
        }
        else
        {
            fnd() += fld[celli];
        }
    }
    Pstream::mapCombineGather(regionToSum, plusEqOp<Type>());
    Pstream::mapCombineScatter(regionToSum);

    return regionToSum;
}


// ************************************************************************* //
